"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToggleThemeLegacyButton = void 0;
var react_1 = __importDefault(require("react"));
var material_1 = require("@mui/material");
var Brightness4_1 = __importDefault(require("@mui/icons-material/Brightness4"));
var Brightness7_1 = __importDefault(require("@mui/icons-material/Brightness7"));
var ra_core_1 = require("ra-core");
var theme_1 = require("../theme");
/**
 * Button toggling the theme (light or dark).
 *
 * @deprecated Set the lightTheme and darkTheme props in the <Admin> component.
 *
 * @example
 * import { AppBar, TitlePortal, ToggleThemeLegacyButton } from 'react-admin';
 *
 * const MyAppBar = () => (
 *     <AppBar>
 *         <TitlePortal />
 *         <ToggleThemeButton lightTheme={lightTheme} darkTheme={darkTheme} />
 *     </AppBar>
 * );
 *
 * const MyLayout = props => <Layout {...props} appBar={MyAppBar} />;
 */
var ToggleThemeLegacyButton = function (props) {
    var translate = (0, ra_core_1.useTranslate)();
    var darkTheme = props.darkTheme, lightTheme = props.lightTheme;
    var _a = (0, theme_1.useTheme)(), theme = _a[0], setTheme = _a[1];
    // @ts-ignore
    var isDark = theme === 'dark' || (theme === null || theme === void 0 ? void 0 : theme.palette.mode) === 'dark';
    var handleTogglePaletteType = function () {
        setTheme(isDark ? lightTheme : darkTheme);
    };
    var toggleThemeTitle = translate('ra.action.toggle_theme', {
        _: 'Toggle Theme',
    });
    return (react_1.default.createElement(material_1.Tooltip, { title: toggleThemeTitle, enterDelay: 300 },
        react_1.default.createElement(material_1.IconButton, { color: "inherit", onClick: handleTogglePaletteType, "aria-label": toggleThemeTitle }, isDark ? react_1.default.createElement(Brightness7_1.default, null) : react_1.default.createElement(Brightness4_1.default, null))));
};
exports.ToggleThemeLegacyButton = ToggleThemeLegacyButton;
//# sourceMappingURL=ToggleThemeLegacyButton.js.map