import { ReactNode } from 'react';
import { RaThemeOptions } from './types';
/**
 * This sets the Material UI theme based on the preferred theme type.
 *
 * @param props
 * @param props.children The children of the component.
 * @param {ThemeOptions} props.theme The initial theme. Optional, use the one from the context if not provided.
 *
 * @example
 *
 * import { ThemesContext, ThemeProvider } from 'react-admin';
 *
 * const App = () => (
 *    <ThemesContext.Provider value={{ lightTheme, darkTheme }}>
 *      <ThemeProvider>
 *        <Button>Test</Button>
 *      </ThemeProvider>
 *   </ThemesContext.Provider>
 * );
 */
export declare const ThemeProvider: ({ children, theme: themeOverride, }: ThemeProviderProps) => JSX.Element;
export interface ThemeProviderProps {
    children: ReactNode;
    /**
     * @deprecated Use the `ThemesProvider` component instead.
     */
    theme?: RaThemeOptions;
}
//# sourceMappingURL=ThemeProvider.d.ts.map